package com.install4j.api.context;

/**
 * This interface provides information about launchers.
 * Launchers are configured on the "Launchers" section in the install4j GUI.
 * <p>Objects of this type are returned by {@link Context#getLaunchers()} and {@link Context#getLauncherById(String)}.
 *
 * @author ej-technologies GmbH
 */
public interface LauncherSetup {

    /**
     * Get the relative file name for the launcher.
     * @return the relative file name.
     */
    String getRelativeFileName();

    /**
     * Get the ID of the launcher. The ID of a launcher
     * can be displayed the install4j GUI by invoking Launcher->Show Launcher IDs from the main
     * menu when the Launchers section is active.
     * @return the ID.
     */
    String getId();

    /**
     * Get the type of the launcher.
     * @return the type
     */
    LauncherType getType();

    /**
     * Returns whether the launcher is excluded from menu integration. This concerns start menu entries on Windows
     * and the creation of links on Unix that are performed by the "Create standard program group" action.
     * @return <tt>true</tt> or <tt>false</tt>.
     */
    boolean isExcludeFromMenu();

    /**
     * Returns whether the launcher is the uninstaller.
     * @return <tt>true</tt> or <tt>false</tt>.
     */
    boolean isUninstaller();

    /**
     * Return the name of the installer as configured in the instal4j GUI.
     * @return the name
     */
    String getName();
}
