package com.install4j.api.events;

import com.install4j.api.context.Context;

import java.io.File;

/**
 * The event object that is passed to installer event listeners for file installation event types.
 * Event listeners are registered in the {@link com.install4j.api.context.InstallerContext}.
 * <p>This event object contains additional information about the installed file.
 * The event types {@link EventType#BEFORE_INSTALL_FILE} and {@link EventType#AFTER_INSTALL_FILE}
 * produce this event object when fired.
 * @author ej-technologies GmbH
 * @see InstallerEventListener
 * @see com.install4j.api.context.InstallerContext#addInstallerEventListener(InstallerEventListener)
 *
 */
public class InstallerFileEvent extends InstallerEvent {
    private File destinationFile;

    /**
     * The constructor is called by the framework.
     * @param source the event source
     * @param context the context
     * @param type the event type.
     * @param success whether the operation associated with the event was successful
     * @param destinationFile the installed file
     */
    public InstallerFileEvent(Object source, Context context, EventType type, boolean success, File destinationFile) {
        super(source, context, type, success);
        this.destinationFile = destinationFile;
    }

    /**
     * Get the installed file location that is associated with this event.
     * @return the file
     */
    public File getDestinationFile() {
        return destinationFile;
    }

    public String toString() {
        return super.toString() + " [file " + destinationFile + "]";
    }

    public String getVerbose() {
        String ret = super.getVerbose() + ": " + destinationFile;
        if (getType() == EventType.BEFORE_INSTALL_FILE) {
            ret += "; exists: " + destinationFile.exists();
        }
        return ret;
    }
}
