package com.install4j.api.launcher;

import com.exe4j.Controller;
import com.install4j.runtime.installer.helper.InstallerUtil;

import java.lang.reflect.InvocationTargetException;
import java.util.EventListener;

/**
 *
 * <p>This class allows you to register a listener to receive startup
 * events in single instance mode on Microsoft Windows and
 * file open events on Mac OS X.</p>
 *
 * On OS X, this is a facade for the Apple 1.4 and 1.5 Java extensions.
 * If you want to use additional features, please use the com.apple.eawt.Application
 * class directly. It is contained in ui.jar on every OS X system. For detailed functionality
 * please refer to <a href="http://developer.apple.com/documentation/Java/Reference/1.4.2/appledoc/api/index.html" target="_top">http://developer.apple.com/documentation/Java/Reference/1.4.2/appledoc/api/index.html</a>.
 *
 * @author ej-technologies GmbH
 *
 **/
public class StartupNotification {
    private static Listener listener;

    /**
     * Register a listener to receive startup events in single instance mode on
     * Microsoft Windows or to receive file open events on OS X.
     * @param listener the listener
     */
    public static void registerStartupListener(final Listener listener) {
        if (InstallerUtil.isWindows()) {
            StartupNotification.listener = listener;
            if (listener != null) {
                Controller.registerStartupListener(new ListenerAdapter());
            }
        } else if (InstallerUtil.isMacOS() && InstallerUtil.isAtLeastJava14()) {
            try {
                Class.forName("com.install4j.runtime.installer.platform.macos.MacFileAssociations").getMethod("setStartupListener",
                        new Class[] { Listener.class }).invoke(null, new Object[] { listener });
            } catch (ClassNotFoundException e) {
                e.printStackTrace();
            } catch (NoSuchMethodException e) {
                e.printStackTrace();
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            } catch (InvocationTargetException e) {
                e.printStackTrace();
            }
        }
    }


    /**
     * Sets if the Quit command should be handled on OS X (that means if the application
     * should quit when the command is invoked). This is true be default.
     * @param handleQuit true if quit should be handled
     */
    public static void setHandleQuit(boolean handleQuit) {
        if (InstallerUtil.isMacOS() && InstallerUtil.isAtLeastJava14()) {
            // reflection neded for idea
            try {
                Class.forName("com.install4j.runtime.installer.platform.macos.MacFileAssociations").getMethod("setHandleQuit",
                        new Class[] { boolean.class }).invoke(null, new Object[] {handleQuit ? Boolean.TRUE : Boolean.FALSE});
            } catch (ClassNotFoundException e) {
                e.printStackTrace();
            } catch (NoSuchMethodException e) {
                e.printStackTrace();
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            } catch (InvocationTargetException e) {
                e.printStackTrace();
            }
        }
    }


    /**
     * The interface for startup events in single instance mode or for open file events on OS X.
     *
     * @author ej-technologies GmbH
     *
    */
    public interface Listener extends EventListener {
        /**
         * Will be called when the executable is started again or when a file open event is received.
         * Note that each invocation may be from a separate thread. If you have to serialize
         * calls into this method, please synchronize the implementation.
         * @param parameters the parameters of the invocation, or the file to open on OS X
         *  <p<b>Note:</b> any default arguments defined for the launcher will not be
         *  passed again here</p>.
         */
        public void startupPerformed(String parameters);
    }

    private static class ListenerAdapter implements Controller.StartupListener {
        public void startupPerformed(String parameters) {
            if (listener != null) {
                listener.startupPerformed(parameters);
            }
        }
    }
}
